==> haskell-torrent-10000.1.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 torrent
version:              10000.1.1
visibility:           public
id:                   torrent-10000.1.1-CP4yA0xW9Wg3FMLzCJcpqH
key:                  torrent-10000.1.1-CP4yA0xW9Wg3FMLzCJcpqH
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  c48768af3c3db2b744a320e22a0b377d
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-8.10.1/site-local/torrent-10000.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/torrent-10000.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/torrent-10000.1.1
hs-libraries:         HStorrent-10000.1.1-CP4yA0xW9Wg3FMLzCJcpqH
depends:
    base-4.14.0.0 bencode-0.6.1.1-FQTNjAIzxnKD2c8REPFo3i binary-0.8.8.0
    bytestring-0.10.10.0 containers-0.6.2.1 filepath-1.4.2.1
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-torrent-10000.1.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 torrent
version:              10000.1.1
visibility:           public
id:                   torrent-10000.1.1-1rlUNRmi2zT2u4wVODqL5M
key:                  torrent-10000.1.1-1rlUNRmi2zT2u4wVODqL5M
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  69e187d419fb4949b1f3ab6e011cf075
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-8.10.1/site-local/torrent-10000.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/torrent-10000.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/torrent-10000.1.1
hs-libraries:         HStorrent-10000.1.1-1rlUNRmi2zT2u4wVODqL5M
depends:
    base-4.14.0.0 bencode-0.6.1.1-4GA2NMgV2mn4fo4KLJEJPW binary-0.8.8.0
    bytestring-0.10.10.0 containers-0.6.2.1 filepath-1.4.2.1
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
